@@ -1,10 +1,8 @@
 #
 # SymPy expression writer
 #
-# This file is part of Myokit
-#  Copyright 2011-2018 Maastricht University, University of Oxford
-#  Licensed under the GNU General Public License v3.0
-#  See: http://myokit.org
+# This file is part of Myokit.
+# See http://myokit.org for copyright, sharing, and licensing details.
 #
 from __future__ import absolute_import, division
 from __future__ import print_function, unicode_literals
@@ -49,7 +47,7 @@ class SymPyExpressionWriter(myokit.formats.ExpressionWriter):
         """
         try:
             action = self._op_map[type(e)]
-        except KeyError:
+        except KeyError:    # pragma: no cover
             raise ValueError('Unsupported type: ' + str(type(e)))
         return action(e)
 
